@@ -38,7 +38,7 @@ python_path = []
 
 class PythonCodeCompletionModel(AbstractCodeCompletionModel):
 
-    TITLE_AUTOCOMPLETATION = "Python Auto Complete"
+    TITLE_AUTOCOMPLETION = "Python Auto Complete"
     MIMETYPES = ['text/plain', 'text/x-python']
     OPERATORS = ["=", " ", "[", "]", "(", ")", "{", "}", ":", ">", "<",
                  "+", "-", "*", "/", "%", " and ", " or ", ","]
